@@ -7,6 +7,7 @@ from qhub.provider.oauth.auth0 import create_client
 from qhub.provider.cicd import github
 from qhub.provider import git
 from qhub.constants import DEFAULT_TERRAFORM_VERSION
+from qhub.provider.cloud import digital_ocean
 
 
 BASE_CONFIGURATION = {
@@ -59,7 +60,7 @@ OAUTH_AUTH0 = {
 
 DIGITAL_OCEAN = {
     "region": "nyc3",
-    "kubernetes_version": "1.18.8-do.0",
+    "kubernetes_version": "PLACEHOLDER",
     "node_groups": {
         "general": {"instance": "s-2vcpu-4gb", "min_nodes": 1, "max_nodes": 1},
         "user": {"instance": "s-2vcpu-4gb", "min_nodes": 1, "max_nodes": 4},
@@ -184,11 +185,12 @@ def render_config(
     cloud_provider,
     ci_provider,
     repository,
-    repository_auto_provision,
     oauth_provider,
-    oauth_auto_provision,
-    disable_prompt,
     terraform_version=DEFAULT_TERRAFORM_VERSION,
+    repository_auto_provision=False,
+    oauth_auto_provision=False,
+    kubernetes_version=None,
+    disable_prompt=False,
 ):
     config = BASE_CONFIGURATION
     config["provider"] = cloud_provider
@@ -216,7 +218,7 @@ def render_config(
             config["security"]["authentication"]["config"]["client_id"] = input(
                 "Github client_id: "
             )
-            config["security"]["authentication"]["config"]["client_id"] = input(
+            config["security"]["authentication"]["config"]["client_secret"] = input(
                 "Github client_secret: "
             )
             config["security"]["authentication"]["config"][
@@ -230,8 +232,21 @@ def render_config(
 
     if cloud_provider == "do":
         config["digital_ocean"] = DIGITAL_OCEAN
+        if kubernetes_version:
+            config["digital_ocean"]["kubernetes_version"] = kubernetes_version
+        else:
+            # first kubernetes version returned by Digital Ocean api is
+            # the newest version of kubernetes supported this field needs
+            # to be dynamically filled since digital ocean updates the
+            # versions so frequently
+            config["digital_ocean"][
+                "kubernetes_version"
+            ] = digital_ocean.kubernetes_versions()[0]["slug"]
     elif cloud_provider == "gcp":
         config["google_cloud_platform"] = GOOGLE_PLATFORM
+        if kubernetes_version:
+            config["google_cloud_platform"]["kubernetes_version"] = kubernetes_version
+
         if "PROJECT_ID" in os.environ:
             config["google_cloud_platform"]["project"] = os.environ["PROJECT_ID"]
         elif not disable_prompt:
@@ -240,6 +255,8 @@ def render_config(
             )
     elif cloud_provider == "aws":
         config["amazon_web_services"] = AMAZON_WEB_SERVICES
+        if kubernetes_version:
+            config["amazon_web_services"]["kubernetes_version"] = kubernetes_version
 
     config["profiles"] = DEFAULT_PROFILES
     config["environments"] = DEFAULT_ENVIRONMENTS
